summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--.pyenchant_pylint_custom_dict.txt2
-rw-r--r--ChangeLog10
-rw-r--r--doc/user_guide/ide-integration.rst14
-rw-r--r--elisp/pylint-flymake.el2
-rw-r--r--examples/custom.py2
-rw-r--r--pylint/checkers/dunder_methods.py4
-rw-r--r--pylint/checkers/non_ascii_names.py2
-rw-r--r--pylint/checkers/similar.py16
-rw-r--r--pylint/checkers/strings.py2
-rw-r--r--pylint/checkers/typecheck.py4
-rw-r--r--pylint/checkers/unicode.py4
-rw-r--r--pylint/checkers/utils.py2
-rw-r--r--pylint/checkers/variables.py2
-rw-r--r--pylint/config/arguments_manager.py4
-rwxr-xr-xpylint/epylint.py2
-rw-r--r--pylint/extensions/private_import.py5
-rw-r--r--pylint/lint/pylinter.py2
-rw-r--r--pylint/pyreverse/diadefslib.py5
-rw-r--r--pylint/pyreverse/utils.py4
-rw-r--r--pylint/pyreverse/vcg_printer.py2
-rw-r--r--pylint/reporters/text.py2
-rw-r--r--tests/checkers/unittest_variables.py2
-rw-r--r--tests/functional/i/iterable_context.py4
-rw-r--r--tests/functional/u/unnecessary/unnecessary_dunder_call.py2
-rw-r--r--tests/functional/u/unused/unused_private_member.py2
-rw-r--r--tests/pyreverse/test_main.py2
-rw-r--r--tests/test_check_parallel.py4
-rw-r--r--tests/test_functional.py4
-rw-r--r--tests/test_regr.py2
-rw-r--r--tests/test_self.py3
30 files changed, 56 insertions, 61 deletions
diff --git a/.pyenchant_pylint_custom_dict.txt b/.pyenchant_pylint_custom_dict.txt
index 60a3a6f06..6d43dc23a 100644
--- a/.pyenchant_pylint_custom_dict.txt
+++ b/.pyenchant_pylint_custom_dict.txt
@@ -144,6 +144,7 @@ INI
init
initializer
inlinevar
+instantiated
instantiation
isdir
isfile
@@ -312,6 +313,7 @@ supcls
superclass
symilar
sys
+tbump
tempfile
testcase
testdata
diff --git a/ChangeLog b/ChangeLog
index 5bcbe5b61..20fe4afb2 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -3188,7 +3188,7 @@ Release date: 2019-09-24
* Allow a ``.`` as a prefix for Sphinx name resolution.
-* Checkers must now keep a 1 to 1 relationship between "msgid" (ie: C1234) and "symbol" (i.e.: human-readable-symbol)
+* Checkers must now keep a 1 to 1 relationship between "msgid" (ie: C1234) and "symbol" (i.e. : human-readable-symbol)
* In checkers, an old_names can now be used for multiple new messages and pylint is now a little faster
Caused by #1164. It means if you do a partial old_names for a message definition an exception will tell you that you
@@ -5400,7 +5400,7 @@ Release date: 2014-11-23
* Change default max-line-length to 100 rather than 80
* Drop BaseRawChecker class which were only there for backward
- compat for a while now
+ compatibility for a while now
* Don't try to analyze string formatting with objects coming from
function arguments. Closes issue #373.
@@ -6357,7 +6357,7 @@ Release date: 2009-12-18
* include James Lingard patches for function call arguments checker
- * improved flymake code and doc provided by Derek Harland
+ * improved Flymake code and doc provided by Derek Harland
* refactor and fix the imports checker
@@ -6492,7 +6492,7 @@ Release date: 2008-09-10
generic generated-members option. If the zope option is set, the behaviour
is now to add some default values to generated-members.
- * flymake integration: added bin/epylint and elisp/pylint-flymake.el
+ * Flymake integration: added bin/epylint and elisp/pylint-flymake.el
What's New in Pylint 0.14.0?
@@ -6694,7 +6694,7 @@ Release date: 2006-03-06
* a new typecheck checker, introducing the following checks:
- - E1101, access to unexistent member (implements #10430), remove
+ - E1101, access to nonexistent member (implements #10430), remove
the need of E0201 and so some options has been moved from the
classes checker to this one
- E1102, calling a non callable object
diff --git a/doc/user_guide/ide-integration.rst b/doc/user_guide/ide-integration.rst
index 5f51f3e51..9eeb94db8 100644
--- a/doc/user_guide/ide-integration.rst
+++ b/doc/user_guide/ide-integration.rst
@@ -43,14 +43,14 @@ Pylint is integrated in:
.. _Visual Studio Code: https://code.visualstudio.com/
.. _Jupyter Notebook: https://jupyter.org/
-Using Pylint thru flymake in Emacs
-==================================
+Using Pylint through Flymake in Emacs
+=====================================
-To enable flymake for Python, insert the following into your .emacs:
+To enable Flymake for Python, insert the following into your .emacs:
.. sourcecode:: common-lisp
- ;; Configure flymake for Python
+ ;; Configure Flymake for Python
(when (load "flymake" t)
(defun flymake-pylint-init ()
(let* ((temp-file (flymake-init-create-temp-buffer-copy
@@ -80,16 +80,16 @@ Other things you may find useful to set:
(add-hook 'python-mode-hook '(lambda () (define-key python-mode-map "\C-cp" 'flymake-goto-prev-error)))
-Finally, by default flymake only displays the extra information about the error when you
+Finally, by default Flymake only displays the extra information about the error when you
hover the mouse over the highlighted line. The following will use the minibuffer to display
messages when you the cursor is on the line.
.. sourcecode:: common-lisp
- ;; To avoid having to mouse hover for the error message, these functions make flymake error messages
+ ;; To avoid having to mouse hover for the error message, these functions make Flymake error messages
;; appear in the minibuffer
(defun show-fly-err-at-point ()
- "If the cursor is sitting on a flymake error, display the message in the minibuffer"
+ "If the cursor is sitting on a Flymake error, display the message in the minibuffer"
(require 'cl)
(interactive)
(let ((line-no (line-number-at-pos)))
diff --git a/elisp/pylint-flymake.el b/elisp/pylint-flymake.el
index 6313ba545..ed213bf46 100644
--- a/elisp/pylint-flymake.el
+++ b/elisp/pylint-flymake.el
@@ -1,4 +1,4 @@
-;; Configure flymake for python
+;; Configure Flymake for python
(when (load "flymake" t)
(defun flymake-pylint-init ()
(let* ((temp-file (flymake-init-create-temp-buffer-copy
diff --git a/examples/custom.py b/examples/custom.py
index 83bba5143..526f50ad9 100644
--- a/examples/custom.py
+++ b/examples/custom.py
@@ -15,7 +15,7 @@ class MyAstroidChecker(BaseChecker):
# The name defines a custom section of the config for this checker.
name = "custom"
- # This class variable declares the messages (i.e.the warnings and errors)
+ # This class variable declares the messages (i.e. the warnings and errors)
# that the checker can emit.
msgs = {
# Each message has a code, a message that the user will see,
diff --git a/pylint/checkers/dunder_methods.py b/pylint/checkers/dunder_methods.py
index 354654ca2..f6520ba95 100644
--- a/pylint/checkers/dunder_methods.py
+++ b/pylint/checkers/dunder_methods.py
@@ -125,7 +125,7 @@ class DunderCallChecker(BaseChecker):
since these either have no alternative method of being called or
have a genuine use case for being called manually.
- Additionally we exclude uninstantiated classes since these
+ Additionally, we exclude classes that are not instantiated since these
might be used to access the dunder methods of a base class of an instance.
We also exclude dunder method calls on super() since
these can't be written in an alternative manner.
@@ -171,7 +171,7 @@ class DunderCallChecker(BaseChecker):
):
inf_expr = safe_infer(node.func.expr)
if not (inf_expr in {None, Uninferable} or isinstance(inf_expr, Instance)):
- # Skip dunder calls to uninstantiated classes.
+ # Skip dunder calls to non instantiated classes.
return
self.add_message(
diff --git a/pylint/checkers/non_ascii_names.py b/pylint/checkers/non_ascii_names.py
index 610d1c72f..6e3628063 100644
--- a/pylint/checkers/non_ascii_names.py
+++ b/pylint/checkers/non_ascii_names.py
@@ -149,7 +149,7 @@ class NonAsciiNameChecker(base_checker.BaseChecker):
# Possibilities here:
# - isinstance(node.assign_type(), nodes.Comprehension) == inlinevar
# - isinstance(frame, nodes.Module) == variable (constant?)
- # - some other kind of assigment missed but still most likely a variable
+ # - some other kind of assignment missed but still most likely a variable
self._check_name("variable", node.name, node)
@utils.only_required_for_messages("non-ascii-name")
diff --git a/pylint/checkers/strings.py b/pylint/checkers/strings.py
index 2af5cbd27..51764c8d7 100644
--- a/pylint/checkers/strings.py
+++ b/pylint/checkers/strings.py
@@ -834,7 +834,7 @@ class StringConstantChecker(BaseTokenChecker, BaseRawFileChecker):
):
"""Check for bad escapes in a non-raw string.
- prefix: lowercase string of e.g. 'ur' string prefix markers.
+ prefix: lowercase string of string prefix markers ('ur').
string_body: the un-parsed body of the string, not including the quote
marks.
start_row: integer line number in the source.
diff --git a/pylint/checkers/typecheck.py b/pylint/checkers/typecheck.py
index c7058e5f1..57d947c53 100644
--- a/pylint/checkers/typecheck.py
+++ b/pylint/checkers/typecheck.py
@@ -223,7 +223,7 @@ MSGS: dict[str, MessageDefinitionTuple] = {
"E1101": (
"%s %r has no %r member%s",
"no-member",
- "Used when a variable is accessed for an unexistent member.",
+ "Used when a variable is accessed for a nonexistent member.",
{"old_names": [("E1103", "maybe-no-member")]},
),
"I1101": (
@@ -499,7 +499,7 @@ def _emit_no_member(
# * Walk up recursively until if statement is found.
# * Check if condition can be inferred as `Const`,
# would evaluate as `False`,
- # and wheater the node is part of the `body`.
+ # and whether the node is part of the `body`.
# * Continue checking until scope of node is reached.
scope: nodes.NodeNG = node.scope()
node_origin: nodes.NodeNG = node
diff --git a/pylint/checkers/unicode.py b/pylint/checkers/unicode.py
index d63469591..b5123ef17 100644
--- a/pylint/checkers/unicode.py
+++ b/pylint/checkers/unicode.py
@@ -250,8 +250,8 @@ def _cached_encode_search(string: str, encoding: str) -> bytes:
def _fix_utf16_32_line_stream(steam: Iterable[bytes], codec: str) -> Iterable[bytes]:
"""Handle line ending for UTF16 and UTF32 correctly.
- Currently Python simply strips the required zeros after \n after the
- line ending. Leading to lines that can't be decoded propery
+ Currently, Python simply strips the required zeros after \n after the
+ line ending. Leading to lines that can't be decoded properly
"""
if not codec.startswith("utf-16") and not codec.startswith("utf-32"):
yield from steam
diff --git a/pylint/checkers/utils.py b/pylint/checkers/utils.py
index 383550415..dee3fe9ce 100644
--- a/pylint/checkers/utils.py
+++ b/pylint/checkers/utils.py
@@ -1399,7 +1399,7 @@ def is_node_in_type_annotation_context(node: nodes.NodeNG) -> bool:
"""Check if node is in type annotation context.
Check for 'AnnAssign', function 'Arguments',
- or part of function return type anntation.
+ or part of function return type annotation.
"""
# pylint: disable=too-many-boolean-expressions
current_node, parent_node = node, node.parent
diff --git a/pylint/checkers/variables.py b/pylint/checkers/variables.py
index ab39c55ac..a52daab6c 100644
--- a/pylint/checkers/variables.py
+++ b/pylint/checkers/variables.py
@@ -2586,7 +2586,7 @@ class VariablesChecker(BaseChecker):
len(values),
),
)
- # attempt to check unpacking may be possible (i.e.RHS is iterable)
+ # attempt to check unpacking may be possible (i.e. RHS is iterable)
elif not utils.is_iterable(inferred):
self.add_message(
"unpacking-non-sequence",
diff --git a/pylint/config/arguments_manager.py b/pylint/config/arguments_manager.py
index 1ba9a31e3..96c337a02 100644
--- a/pylint/config/arguments_manager.py
+++ b/pylint/config/arguments_manager.py
@@ -488,7 +488,7 @@ class _ArgumentsManager:
"""DEPRECATED: Read the configuration file but do not load it (i.e. dispatching
values to each option's provider)
- :raises OSError: Whem the specified config file doesn't exist
+ :raises OSError: When the specified config file doesn't exist
"""
warnings.warn(
"read_config_file has been deprecated. It will be removed in pylint 3.0.",
@@ -529,7 +529,7 @@ class _ArgumentsManager:
) -> None: # pragma: no cover
"""DEPRECATED: Parse and handle errors of a toml configuration file.
- TODO: 3.0: Remove depreacted method.
+ TODO: 3.0: Remove deprecated method.
"""
with open(config_file, mode="rb") as fp:
content = tomllib.load(fp)
diff --git a/pylint/epylint.py b/pylint/epylint.py
index 8a183e384..049ab01a5 100755
--- a/pylint/epylint.py
+++ b/pylint/epylint.py
@@ -7,7 +7,7 @@
"""Emacs and Flymake compatible Pylint.
-This script is for integration with Emacs and is compatible with flymake mode.
+This script is for integration with Emacs and is compatible with Flymake mode.
epylint walks out of python packages before invoking pylint. This avoids
reporting import errors that occur when a module within a package uses the
diff --git a/pylint/extensions/private_import.py b/pylint/extensions/private_import.py
index 3fb36f27b..39fa4c22a 100644
--- a/pylint/extensions/private_import.py
+++ b/pylint/extensions/private_import.py
@@ -188,7 +188,7 @@ class PrivateImportChecker(BaseChecker):
node: nodes.Attribute | nodes.Subscript | nodes.Name | None,
all_used_type_annotations: dict[str, bool],
) -> str | None:
- """Handles the possiblity of an annotation either being a Name, i.e. just type,
+ """Handles the possibility of an annotation either being a Name, i.e. just type,
or a Subscript e.g. `Optional[type]` or an Attribute, e.g. `pylint.lint.linter`.
"""
if isinstance(node, nodes.Name) and node.name not in all_used_type_annotations:
@@ -216,7 +216,8 @@ class PrivateImportChecker(BaseChecker):
) -> bool:
"""Returns True if no assignments involve accessing `private_name`."""
if all(not assignment.value for assignment in assignments):
- # Variable annotated but unassigned is unallowed because there may be a possible illegal access elsewhere
+ # Variable annotated but unassigned is not allowed because there may be
+ # possible illegal access elsewhere
return False
for assignment in assignments:
current_attribute = None
diff --git a/pylint/lint/pylinter.py b/pylint/lint/pylinter.py
index 14ca1f934..50f354657 100644
--- a/pylint/lint/pylinter.py
+++ b/pylint/lint/pylinter.py
@@ -210,7 +210,7 @@ class PyLinter(
generation. It is itself both a raw checker and an astroid checker in order
to:
* handle message activation / deactivation at the module level
- * handle some basic but necessary stats'data (number of classes, methods...)
+ * handle some basic but necessary stats' data (number of classes, methods...)
IDE plugin developers: you may have to call
`astroid.builder.MANAGER.astroid_cache.clear()` across runs if you want
diff --git a/pylint/pyreverse/diadefslib.py b/pylint/pyreverse/diadefslib.py
index 35df9cb02..8a0b2e1a9 100644
--- a/pylint/pyreverse/diadefslib.py
+++ b/pylint/pyreverse/diadefslib.py
@@ -173,10 +173,7 @@ class ClassDiadefGenerator(DiaDefGenerator):
"""
def class_diagram(self, project, klass):
- """Return a class diagram definition for the given klass and its
- related klasses
- """
-
+ """Return a class diagram definition for the class and related classes."""
self.classdiagram = ClassDiagram(klass, self.config.mode)
if len(project.modules) > 1:
module, klass = klass.rsplit(".", 1)
diff --git a/pylint/pyreverse/utils.py b/pylint/pyreverse/utils.py
index 393ff8c77..be496dfc6 100644
--- a/pylint/pyreverse/utils.py
+++ b/pylint/pyreverse/utils.py
@@ -79,12 +79,12 @@ def is_final(node):
def is_interface(node):
- # bw compat
+ # bw compatibility
return node.type == "interface"
def is_exception(node):
- # bw compat
+ # bw compatibility
return node.type == "exception"
diff --git a/pylint/pyreverse/vcg_printer.py b/pylint/pyreverse/vcg_printer.py
index 288be3dd0..ec7152baa 100644
--- a/pylint/pyreverse/vcg_printer.py
+++ b/pylint/pyreverse/vcg_printer.py
@@ -2,7 +2,7 @@
# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
-"""Functions to generate files readable with Georg Sander's vcg
+"""Functions to generate files readable with George Sander's vcg
(Visualization of Compiler Graphs).
You can download vcg at https://rw4.cs.uni-sb.de/~sander/html/gshome.html
diff --git a/pylint/reporters/text.py b/pylint/reporters/text.py
index a75995c40..9ab8f7479 100644
--- a/pylint/reporters/text.py
+++ b/pylint/reporters/text.py
@@ -75,7 +75,7 @@ def _get_ansi_code(msg_style: MessageStyle) -> str:
:param msg_style: the message style
- :raise KeyError: if an unexistent color or style identifier is given
+ :raise KeyError: if a nonexistent color or style identifier is given
:return: the built escape code
"""
diff --git a/tests/checkers/unittest_variables.py b/tests/checkers/unittest_variables.py
index 98f15d299..d810163d2 100644
--- a/tests/checkers/unittest_variables.py
+++ b/tests/checkers/unittest_variables.py
@@ -44,7 +44,7 @@ class TestVariablesCheckerWithTearDown(CheckerTestCase):
@set_config(callbacks=("callback_", "_callback"))
def test_custom_callback_string(self) -> None:
- """Test the --calbacks option works."""
+ """Test the --callbacks option works."""
node = astroid.extract_node(
"""
def callback_one(abc):
diff --git a/tests/functional/i/iterable_context.py b/tests/functional/i/iterable_context.py
index 0d221eef9..adc279f9b 100644
--- a/tests/functional/i/iterable_context.py
+++ b/tests/functional/i/iterable_context.py
@@ -135,10 +135,10 @@ class ManagedAccessViewMixin(object):
return self.access_requirements
def dispatch(self, *_args, **_kwargs):
- klasses = self.get_access_requirements()
+ classes = self.get_access_requirements()
# no error should be emitted here
- for requirement in klasses:
+ for requirement in classes:
print(requirement)
class BaseType(object):
diff --git a/tests/functional/u/unnecessary/unnecessary_dunder_call.py b/tests/functional/u/unnecessary/unnecessary_dunder_call.py
index c89fb2c75..e1986a937 100644
--- a/tests/functional/u/unnecessary/unnecessary_dunder_call.py
+++ b/tests/functional/u/unnecessary/unnecessary_dunder_call.py
@@ -109,7 +109,7 @@ class Base:
my_instance_name = x.__class__.__name__
my_pkg_version = pkg.__version__
-# Allow use of dunder methods on uninstantiated classes
+# Allow use of dunder methods on non instantiated classes
MANUAL_SELF = int.__add__(1, 1)
MY_DICT = {"a": 1, "b": 2}
dict.__setitem__(MY_DICT, "key", "value")
diff --git a/tests/functional/u/unused/unused_private_member.py b/tests/functional/u/unused/unused_private_member.py
index d69d7eb11..3bfab592e 100644
--- a/tests/functional/u/unused/unused_private_member.py
+++ b/tests/functional/u/unused/unused_private_member.py
@@ -109,7 +109,7 @@ print(k.ninetyfive)
# https://github.com/PyCQA/pylint/issues/4657
# Mutation of class member with cls should not fire a false-positive
class FalsePositive4657:
- """False positivie tests for 4657"""
+ """False positive tests for 4657"""
__attr_a = None
__attr_b = 'b'
diff --git a/tests/pyreverse/test_main.py b/tests/pyreverse/test_main.py
index 06a775b6e..69a6ddb26 100644
--- a/tests/pyreverse/test_main.py
+++ b/tests/pyreverse/test_main.py
@@ -157,7 +157,7 @@ def test_command_line_arguments_yes_no(
) -> None:
"""Regression test for the --module-names option.
- Make sure that we supprot --module-names=yes syntax instead
+ Make sure that we support --module-names=yes syntax instead
of using it as a flag.
"""
with pytest.raises(SystemExit) as wrapped_sysexit:
diff --git a/tests/test_check_parallel.py b/tests/test_check_parallel.py
index 79a408fd7..d531bcb29 100644
--- a/tests/test_check_parallel.py
+++ b/tests/test_check_parallel.py
@@ -351,7 +351,7 @@ class TestCheckParallel:
assert linter.stats.warning == 0
def test_invoke_single_job(self) -> None:
- """Tests basic checkers functionality using just a single workderdo.
+ """Tests basic checkers functionality using just a single worker.
This is *not* the same -j1 and does not happen under normal operation
"""
@@ -418,7 +418,7 @@ class TestCheckParallel:
without ordering issues, irrespective of the number of workers used and the
number of checkers applied.
- This test becomes more important if we want to change how we parametrise the
+ This test becomes more important if we want to change how we parametrize the
checkers, for example if we aim to batch the files across jobs.
"""
diff --git a/tests/test_functional.py b/tests/test_functional.py
index a286e8f2a..74b541bcf 100644
--- a/tests/test_functional.py
+++ b/tests/test_functional.py
@@ -22,10 +22,6 @@ from pylint.testutils.functional import (
)
from pylint.utils import HAS_ISORT_5
-# TODOs
-# - implement exhaustivity tests
-
-
FUNCTIONAL_DIR = Path(__file__).parent.resolve() / "functional"
diff --git a/tests/test_regr.py b/tests/test_regr.py
index 677f1912e..a2c7a9f5f 100644
--- a/tests/test_regr.py
+++ b/tests/test_regr.py
@@ -124,7 +124,7 @@ def test_check_package___init__(finalize_linter: PyLinter) -> None:
# pylint: disable-next=fixme
# TODO: 3.0: Test are broken because of property shenanigans of config attribute
-# Renable after some of the old attributes have been removed after deprecation period
+# Re-enable after some of the old attributes have been removed after deprecation period
@pytest.mark.xfail
def test_pylint_config_attr() -> None:
mod = astroid.MANAGER.ast_from_module_name("pylint.lint.pylinter")
diff --git a/tests/test_self.py b/tests/test_self.py
index 233a7d3c1..a77b5d49c 100644
--- a/tests/test_self.py
+++ b/tests/test_self.py
@@ -570,8 +570,7 @@ class TestRunTC:
expected_output=expected,
)
- # this code needs to work w/ and w/o a file named a/b.py on the
- # harddisk.
+ # this code needs to work w/ and w/o a file named a/b.py on the hard disk.
with mock.patch("pylint.lint.pylinter._read_stdin", return_value=b_code):
self._test_output(
[
diff --git a/pylint/checkers/similar.py b/pylint/checkers/similar.py
index d50c15c0a..3b7d5275e 100644
--- a/pylint/checkers/similar.py
+++ b/pylint/checkers/similar.py
@@ -245,13 +245,13 @@ def hash_lineset(
return hash2index, index2lines
-def remove_successives(all_couples: CplIndexToCplLines_T) -> None:
+def remove_successive(all_couples: CplIndexToCplLines_T) -> None:
"""Removes all successive entries in the dictionary in argument.
:param all_couples: collection that has to be cleaned up from successives entries.
The keys are couples of indices that mark the beginning of common entries
in both linesets. The values have two parts. The first one is the couple
of starting and ending line numbers of common successives lines in the first file.
The second part is the same for the second file.
For example consider the following dict:
@@ -261,11 +261,11 @@ def remove_successives(all_couples: CplIndexToCplLines_T) -> None:
(23, 79): ([15, 19], [45, 49]),
(12, 35): ([6, 10], [28, 32])}
There are two successives keys (11, 34) and (12, 35).
It means there are two consecutive similar chunks of lines in both files.
Thus remove last entry and update the last line numbers in the first entry
- >>> remove_successives(all_couples)
+ >>> remove_successive(all_couples)
>>> all_couples
{(11, 34): ([5, 10], [27, 32]),
(23, 79): ([15, 19], [45, 49])}
@@ -300,14 +300,14 @@ def filter_noncode_lines(
That is to say the number of common successive stripped
lines except those that do not contain code (for example
- a line with only an ending parathensis)
+ a line with only an ending parenthesis)
:param ls_1: first lineset
:param stindex_1: first lineset starting index
:param ls_2: second lineset
:param stindex_2: second lineset starting index
:param common_lines_nb: number of common successive stripped lines before being filtered from non code lines
:return: the number of common successives stripped lines that contain code
"""
stripped_l1 = [
lspecif.text
@@ -506,7 +506,7 @@ class Similar:
effective_cmn_lines_nb=self.namespace.min_similarity_lines,
)
- remove_successives(all_couples)
+ remove_successive(all_couples)
for cml_stripped_l, cmn_l in all_couples.items():
start_index_1 = cml_stripped_l.fst_lineset_index
@@ -245,13 +245,13 @@ def hash_lineset(
"""Removes all successive entries in the dictionary in argument.
- :param all_couples: collection that has to be cleaned up from successives entries.
+ :param all_couples: collection that has to be cleaned up from successive entries.
The keys are couples of indices that mark the beginning of common entries
in both linesets. The values have two parts. The first one is the couple
@@ -245,13 +245,13 @@ def hash_lineset(
The keys are couples of indices that mark the beginning of common entries
in both linesets. The values have two parts. The first one is the couple
- of starting and ending line numbers of common successives lines in the first file.
+ of starting and ending line numbers of common successive lines in the first file.
The second part is the same for the second file.
For example consider the following dict:
@@ -261,11 +261,11 @@ def remove_successives(all_couples: CplIndexToCplLines_T) -> None:
(23, 79): ([15, 19], [45, 49]),
(12, 35): ([6, 10], [28, 32])}
- There are two successives keys (11, 34) and (12, 35).
+ There are two successive keys (11, 34) and (12, 35).
It means there are two consecutive similar chunks of lines in both files.
Thus remove last entry and update the last line numbers in the first entry
@@ -300,14 +300,14 @@ def filter_noncode_lines(
:param stindex_2: second lineset starting index
:param common_lines_nb: number of common successive stripped lines before being filtered from non code lines
- :return: the number of common successives stripped lines that contain code
+ :return: the number of common successive stripped lines that contain code
"""
stripped_l1 = [